@@ -64,6 +64,7 @@ public:
     bool sendSms(AsyncTaskToken *token);
     bool getVoicemail(AsyncTaskToken *token);
     bool markInboxEntryAsRead(AsyncTaskToken *token);
+    bool deleteInboxEntry(AsyncTaskToken *token);
 ////////////////////////////////////////////////////////////////////////////////
 
 signals:
@@ -117,6 +118,10 @@ private slots:
     void onMarkAsRead(bool success, const QByteArray &response,
                       QNetworkReply *reply, void *ctx);
 
+    // Delete inbox entry
+    void onEntryDeleted(bool success, const QByteArray &response,
+                        QNetworkReply *reply, void *ctx);
+
     // Get voicemail
     void onVmail(bool success, const QByteArray &response, QNetworkReply *reply,
                  void *ctx);
